Documentation
¶
Index ¶
- type EnquedSubscription
- type Gear
- func (gear *Gear) EnqueuedSubscriptions(methods []string, rtypes []gear_client.ResponseType, ...) SubscriptionFunc
- func (gear *Gear) EnqueuedSubscriptionsOptional(enq []*EnquedSubscription, interruptions ...*Interruption) SubscriptionFunc
- func (gear *Gear) EventsSubscription() SubscriptionFunc
- func (gear *Gear) GetCalls() *calls.Calls
- func (gear *Gear) GetClient() gear_client.IClient
- func (gear *Gear) GetConfig() *config.Scheme
- func (gear *Gear) GetMeta() *metadata.Metadata
- func (gear *Gear) GetRPC() gear_rpc.IGearRPC
- func (gear *Gear) GetWsClient() gear_client.IWsClient
- func (gear *Gear) InitSubscriptions() error
- func (gear *Gear) MergeSubscriptionFunctions(fo ...SubscriptionFunc)
- func (gear *Gear) SubmitAndWatchExtrinsic(args []any, t string) SubscriptionFunc
- type Interruption
- type SendMessage
- type SubscriptionFunc
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EnquedSubscription ¶ added in v1.0.3
type EnquedSubscription struct {
ResponseType gear_client.ResponseType
CallName, ModuleName, Method string
Args []any
IsExtrinsic bool
IsCustomBuilder bool
CustomBuilderKeyRing keyring.IKeyRing
CustomFunc func() error
AfterFinalizationFunc func() error
}
func NewEnq ¶ added in v1.0.3
func NewEnq(responseType gear_client.ResponseType, callName, module, method string, isExtr bool) *EnquedSubscription
type Gear ¶
type Gear struct {
// contains filtered or unexported fields
}
func (*Gear) EnqueuedSubscriptions ¶ added in v1.0.2
func (gear *Gear) EnqueuedSubscriptions(methods []string, rtypes []gear_client.ResponseType, callNames, moduleNames []string, args [][]any, interruptions ...*Interruption) SubscriptionFunc
EnqueuedSubscriptions is
func (*Gear) EnqueuedSubscriptionsOptional ¶ added in v1.0.3
func (gear *Gear) EnqueuedSubscriptionsOptional(enq []*EnquedSubscription, interruptions ...*Interruption) SubscriptionFunc
func (*Gear) EventsSubscription ¶ added in v1.0.2
func (gear *Gear) EventsSubscription() SubscriptionFunc
EventsSubscription implements state_subscribeStorage method
as it is shown in "example/code/example_subscription_upload" (line 23) example function is added via MergeSubscriptionFunctions
func (*Gear) GetClient ¶
func (gear *Gear) GetClient() gear_client.IClient
func (*Gear) GetWsClient ¶ added in v1.0.0
func (gear *Gear) GetWsClient() gear_client.IWsClient
func (*Gear) InitSubscriptions ¶ added in v1.0.2
InitSubscriptions is the main func to handle ws subscriptions Required both AddResponseTypesAndMakeWsConnectionsPool and MergeSubscriptionFunctions had been called before using as it is shown in "example/code/example_subscription_upload" example
func (*Gear) MergeSubscriptionFunctions ¶ added in v1.0.2
func (gear *Gear) MergeSubscriptionFunctions(fo ...SubscriptionFunc)
func (*Gear) SubmitAndWatchExtrinsic ¶ added in v1.0.2
func (gear *Gear) SubmitAndWatchExtrinsic(args []any, t string) SubscriptionFunc
type Interruption ¶ added in v1.0.3
func NewInterruption ¶ added in v1.0.3
func NewInterruption(interruptionCause string, interFunc func() ([]any, error)) *Interruption
type SendMessage ¶ added in v1.0.3
type SubscriptionFunc ¶ added in v1.0.2
type SubscriptionFunc func() error
SubscriptionFunc is a subscription builder func
Directories
¶
| Path | Synopsis |
|---|---|
|
generate-rust-grpc
command
|
|
|
example
|
|
|
balances
command
|
|
|
gear_program
command
|
|
|
gear_program/mailbox
command
|
|
|
gear_program/send_message
command
|
|
|
gear_program/upload_and_create
command
|
|
|
rust-grpc-scale
command
|
|
|
storage
command
|
|
|
voucher
command
|
|
|
internal
|
|
|
lib
|
|
|
pkg
|
|
Click to show internal directories.
Click to hide internal directories.